@@ -1,10 +1,10 @@
 package Net::DNS::ZoneFile;
 
 #
-# $Id: ZoneFile.pm 1456 2016-02-17 13:34:00Z willem $
+# $Id: ZoneFile.pm 1505 2016-09-17 08:12:15Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1456 $)[1];
+$VERSION = (qw$LastChangedRevision: 1505 $)[1];
 
 
 =head1 NAME
@@ -46,13 +46,13 @@ automatically to all subsequent records.
 use strict;
 use integer;
 use Carp;
-
-require FileHandle;
-
-use Net::DNS;
+use FileHandle;
 
 use constant PERLIO => defined eval 'require PerlIO';
 
+require Net::DNS::Domain;
+require Net::DNS::RR;
+
 
 =head1 METHODS
 
@@ -142,9 +142,9 @@ sub read {
 
     $filename = $zonefile->name;
 
-Returns the name of the zone file from which RRs will be read.
-$INCLUDE directives will cause this to differ from the filename
-argument supplied when the object was created.
+Returns the name of the current zone file.
+Embedded $INCLUDE directives will cause this to differ from the
+filename argument supplied when the object was created.
 
 =cut
 
@@ -204,10 +204,12 @@ the compatibility interface described below.
 
     use Net::DNS::ZoneFile;
 
+    $listref = Net::DNS::ZoneFile->read( $filename );
     $listref = Net::DNS::ZoneFile->read( $filename, $include_dir );
 
     $listref = Net::DNS::ZoneFile->readfh( $handle, $include_dir );
 
+    $listref = Net::DNS::ZoneFile->parse(  $string );
     $listref = Net::DNS::ZoneFile->parse(  $string, $include_dir );
     $listref = Net::DNS::ZoneFile->parse( \$string, $include_dir );
 
@@ -427,7 +429,7 @@ sub _generate {				## expand $GENERATE into input stream
 
 	my $handle = new Net::DNS::ZoneFile::Generator( $range, $template, $self->line );
 
-	delete $self->{latest};					# forbid empty owner field
+	delete $self->{latest};					# forget previous owner
 	$self->{parent} = bless {%$self}, ref($self);		# save state, create link
 	$self->{handle} = $handle;
 }
@@ -487,7 +489,7 @@ sub _getline {				## get line from current source
 		} elsif (/^\$TTL/) {				# directive
 			my ( $keyword, $ttl, @etc ) = split;
 			die '$TTL incomplete' unless defined $ttl;
-			$self->{TTL} = new Net::DNS::RR(". $ttl IN A")->ttl;
+			$self->{TTL} = Net::DNS::RR::ttl( {}, $ttl );
 
 		} else {					# unrecognised
 			my ($keyword) = split;
@@ -515,7 +517,8 @@ sub _getRR {				## get RR from current source
 	my $context = $self->{context};
 	my $rr = &$context( sub { Net::DNS::RR->_new_string($_) } );
 
-	$rr->{owner} = $self->{latest}->{owner} if $noname;	# overwrite placeholder
+	my $latest = $self->{latest};				# overwrite placeholder
+	$rr->{owner} = $latest->{owner} if $noname && $latest;
 
 	$self->{class} = $rr->class unless $self->{class};	# propagate RR class
 	$rr->class( $self->{class} );
@@ -535,7 +538,7 @@ sub _include {				## open $INCLUDE file
 	my @discipline = PERLIO ? ( join ':', '<', PerlIO::get_layers $self->{handle} ) : ();
 	my $handle = new FileHandle( $file, @discipline ) or croak qq($! "$file");
 
-	delete $self->{latest};					# forbid empty owner field
+	delete $self->{latest};					# forget previous owner
 	$self->{parent} = bless {%$self}, ref($self);		# save state, create link
 	$self->{context} = origin Net::DNS::Domain($root) if $root;
 	$self->{filename} = $file;
@@ -546,7 +549,7 @@ sub _include {				## open $INCLUDE file
 sub _origin {				## change $ORIGIN (scope: current file)
 	my $self = shift;
 	$self->{context} = origin Net::DNS::Domain(shift);
-	delete $self->{latest};					# forbid empty owner field
+	delete $self->{latest};					# forget previous owner
 }
 
 
